==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebColumnMovingStartEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDetailDescription } from "./WebColumnMovingStartEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnMovingStartEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnMovingStartEventArgsDetailDescriptionMetadata, _super);
    function WebColumnMovingStartEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnMovingStartEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.c(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Source", "ExportedType:WebColumn");
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnMovingStartEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebColumnMovingStartEventArgsDetail", function () { return new WebColumnMovingStartEventArgsDetailDescription(); });
        a.ac("WebColumnMovingStartEventArgsDetail", WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDetailDescriptionMetadata, 'WebColumnMovingStartEventArgsDetailDescriptionMetadata');
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnMovingStartEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebColumnMovingStartEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingStartEventArgsDetailDescription } from "./WebColumnMovingStartEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnMovingStartEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnMovingStartEventArgsDetailDescriptionMetadata, _super);
    function WebColumnMovingStartEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnMovingStartEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingStartEventArgsDetailDescriptionMetadata.c(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnMovingStartEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Source", "ExportedType:WebColumn");
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnMovingStartEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebColumnMovingStartEventArgsDetail", function () { return new WebColumnMovingStartEventArgsDetailDescription(); });
        a.ad("WebColumnMovingStartEventArgsDetail", WebColumnMovingStartEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.$t = markType(WebColumnMovingStartEventArgsDetailDescriptionMetadata, 'WebColumnMovingStartEventArgsDetailDescriptionMetadata');
    WebColumnMovingStartEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingStartEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnMovingStartEventArgsDetailDescriptionMetadata };
